==> mythplugins_0.18.1.orig.tar.gz: mythplugins-0.18.1/mythbrowser/i18n/mythbrowser_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>Bookmarks</name>
    <message>
        <source>MythBrowser: Select group or single site to view</source>
        <translation>MythBrowser: Gruppe oder einzelne Webseite auswählen</translation>
    </message>
</context>
<context>
    <name>BookmarksConfig</name>
    <message>
        <source>MythBrowser Bookmarks Settings</source>
        <translation>MythBrowser Einstellungen</translation>
    </message>
    <message>
        <source>Press the &apos;New Bookmark&apos; button to add a new site/group.
Pressing SPACE/Enter on a selected entry removes it from the listview.</source>
        <translation>&apos;Neuer Eintrag&apos; fügt eine Gruppe oder Webpage hinzu.
SPACE/Enter löscht den selektierten Eintrag.</translation>
    </message>
    <message>
        <source>Zoom [%]:</source>
        <translation>Zoom [%]:</translation>
    </message>
    <message>
        <source>Browser:</source>
        <translation>Browser:</translation>
    </message>
    <message>
        <source>Hide Scrollbars</source>
        <translation>Ohne Scrollbalken</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Seite scrollen</translation>
    </message>
    <message>
        <source>Scroll Speed:</source>
        <translation>Geschw.:</translation>
    </message>
    <message>
        <source>&amp;New Bookmark</source>
        <translation>&amp;Neuer Eintrag</translation>
    </message>
    <message>
        <source>Add a new Website</source>
        <translation>Webseite hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Fertig</translation>
    </message>
</context>
<context>
    <name>PopupBox</name>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>Add New Website</source>
        <translation>Neue Webseite</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
</context>
<context>
    <name>TabView</name>
    <message>
        <source>         Back         </source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>       Next Tab       </source>
        <translation>Nächste Seite</translation>
    </message>
    <message>
        <source>       Prev Tab       </source>
        <translation>Vorherige Seite</translation>
    </message>
    <message>
        <source>Save Link in Bookmarks</source>
        <translation>In Bookmarks speichern</translation>
    </message>
    <message>
        <source>       zoom Out       </source>
        <translation type="obsolete">Schrift kleiner</translation>
    </message>
    <message>
        <source>       zoom In        </source>
        <translation type="obsolete">Schrift grösser</translation>
    </message>
    <message>
        <source>MythBrowser Menu</source>
        <translation>MythBrowser Menü</translation>
    </message>
    <message>
        <source>Enter URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>      Remove Tab      </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>       Zoom Out       </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>       Zoom In        </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythbrowser/i18n/mythbrowser_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>Bookmarks</name>
    <message>
        <source>MythBrowser: Select group or single site to view</source>
        <translation>MythBrowser: Gruppe oder einzelne Webseite auswählen</translation>
    </message>
</context>
<context>
    <name>BookmarksConfig</name>
    <message>
        <source>MythBrowser Bookmarks Settings</source>
        <translation>MythBrowser Einstellungen</translation>
    </message>
    <message>
        <source>Press the &apos;New Bookmark&apos; button to add a new site/group.
Pressing SPACE/Enter on a selected entry removes it from the listview.</source>
        <translation>&apos;Neuer Eintrag&apos; fügt eine Gruppe oder Webpage hinzu.
SPACE/Enter löscht den selektierten Eintrag.</translation>
    </message>
    <message>
        <source>Zoom [%]:</source>
        <translation>Zoom [%]:</translation>
    </message>
    <message>
        <source>Browser:</source>
        <translation>Browser:</translation>
    </message>
    <message>
        <source>Hide Scrollbars</source>
        <translation>Ohne Scrollbalken</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Seite scrollen</translation>
    </message>
    <message>
        <source>Scroll Speed:</source>
        <translation>Geschw.:</translation>
    </message>
    <message>
        <source>&amp;New Bookmark</source>
        <translation>&amp;Neuer Eintrag</translation>
    </message>
    <message>
        <source>Add a new Website</source>
        <translation>Webseite hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Fertig</translation>
    </message>
</context>
<context>
    <name>PopupBox</name>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>Add New Website</source>
        <translation>Neue Webseite</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
</context>
<context>
    <name>TabView</name>
    <message>
        <source>         Back         </source>
        <translation type="obsolete">Zurück</translation>
    </message>
    <message>
        <source>       Next Tab       </source>
        <translation type="obsolete">Nächste Seite</translation>
    </message>
    <message>
        <source>       Prev Tab       </source>
        <translation type="obsolete">Vorherige Seite</translation>
    </message>
    <message>
        <source>Save Link in Bookmarks</source>
        <translation>In Bookmarks speichern</translation>
    </message>
    <message>
        <source>       zoom Out       </source>
        <translation type="obsolete">Schrift kleiner</translation>
    </message>
    <message>
        <source>       zoom In        </source>
        <translation type="obsolete">Schrift grösser</translation>
    </message>
    <message>
        <source>MythBrowser Menu</source>
        <translation>MythBrowser Menü</translation>
    </message>
    <message>
        <source>Enter URL</source>
        <translation>URL eingeben</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Next Tab</source>
        <translation>Nächster Tab</translation>
    </message>
    <message>
        <source>Prev Tab</source>
        <translation>Vorh. Tab</translation>
    </message>
    <message>
        <source>Remove Tab</source>
        <translation>Tab entfernen</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Heraus-Zoomen</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Hinein-Zoomen</translation>
    </message>
    <message>
        <source>Add New Bookmark</source>
        <translation>Neues Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
</context>
</TS>
